Class: EmbedWorkflow::CreateWorkflow201Response

Inherits:
Object
  • Object
show all
Defined in:
lib/embed_workflow/models/create_workflow201_response.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateWorkflow201Response

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 274

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `EmbedWorkflow::CreateWorkflow201Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `EmbedWorkflow::CreateWorkflow201Response`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'account_template_id')
    self. = attributes[:'account_template_id']
  end

  if attributes.key?(:'action_type_ids')
    if (value = attributes[:'action_type_ids']).is_a?(Array)
      self.action_type_ids = value
    end
  end

  if attributes.key?(:'actions_count')
    self.actions_count = attributes[:'actions_count']
  end

  if attributes.key?(:'auto_clone_for_new_users')
    self.auto_clone_for_new_users = attributes[:'auto_clone_for_new_users']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'created_at_string')
    self.created_at_string = attributes[:'created_at_string']
  end

  if attributes.key?(:'created_at_utc')
    self.created_at_utc = attributes[:'created_at_utc']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'event_trigger')
    self.event_trigger = attributes[:'event_trigger']
  end

  if attributes.key?(:'event_trigger_draft')
    self.event_trigger_draft = attributes[:'event_trigger_draft']
  end

  if attributes.key?(:'executions_count')
    self.executions_count = attributes[:'executions_count']
  end

  if attributes.key?(:'groups')
    if (value = attributes[:'groups']).is_a?(Array)
      self.groups = value
    end
  end

  if attributes.key?(:'has_draft')
    self.has_draft = attributes[:'has_draft']
  end

  if attributes.key?(:'is_managed')
    self.is_managed = attributes[:'is_managed']
  end

  if attributes.key?(:'is_template')
    self.is_template = attributes[:'is_template']
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  end

  if attributes.key?(:'last_executed_at')
    self.last_executed_at = attributes[:'last_executed_at']
  end

  if attributes.key?(:'last_executed_at_string')
    self.last_executed_at_string = attributes[:'last_executed_at_string']
  end

  if attributes.key?(:'last_executed_at_utc')
    self.last_executed_at_utc = attributes[:'last_executed_at_utc']
  end

  if attributes.key?(:'last_published_at')
    self.last_published_at = attributes[:'last_published_at']
  end

  if attributes.key?(:'last_published_at_string')
    self.last_published_at_string = attributes[:'last_published_at_string']
  end

  if attributes.key?(:'last_published_at_utc')
    self.last_published_at_utc = attributes[:'last_published_at_utc']
  end

  if attributes.key?(:'managed_by')
    self.managed_by = attributes[:'managed_by']
  end

  if attributes.key?(:'match_conditions')
    self.match_conditions = attributes[:'match_conditions']
  end

  if attributes.key?(:'match_conditions_draft')
    self.match_conditions_draft = attributes[:'match_conditions_draft']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  end

  if attributes.key?(:'on')
    self.on = attributes[:'on']
  end

  if attributes.key?(:'stats')
    if (value = attributes[:'stats']).is_a?(Hash)
      self.stats = value
    end
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'template')
    self.template = attributes[:'template']
  end

  if attributes.key?(:'template_draft')
    self.template_draft = attributes[:'template_draft']
  end

  if attributes.key?(:'trigger_conditions')
    if (value = attributes[:'trigger_conditions']).is_a?(Hash)
      self.trigger_conditions = value
    end
  end

  if attributes.key?(:'trigger_conditions_draft')
    if (value = attributes[:'trigger_conditions_draft']).is_a?(Hash)
      self.trigger_conditions_draft = value
    end
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end

  if attributes.key?(:'updated_at_string')
    self.updated_at_string = attributes[:'updated_at_string']
  end

  if attributes.key?(:'updated_at_utc')
    self.updated_at_utc = attributes[:'updated_at_utc']
  end
end

Instance Attribute Details

#account_template_idObject

ID of the account template this workflow was cloned from



22
23
24
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 22

def 
  @account_template_id
end

#action_type_idsObject

Action type IDs used in this workflow’s template



25
26
27
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 25

def action_type_ids
  @action_type_ids
end

#actions_countObject

Number of actions in the workflow



28
29
30
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 28

def actions_count
  @actions_count
end

#auto_clone_for_new_usersObject

Auto-clone this template for new users (Admin only)



31
32
33
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 31

def auto_clone_for_new_users
  @auto_clone_for_new_users
end

#created_atObject

Created at in specified timezone



34
35
36
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 34

def created_at
  @created_at
end

#created_at_stringObject

Created at formatted as human-readable string



37
38
39
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 37

def created_at_string
  @created_at_string
end

#created_at_utcObject

Created at in UTC



40
41
42
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 40

def created_at_utc
  @created_at_utc
end

#descriptionObject

Description of the workflow



43
44
45
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 43

def description
  @description
end

#event_triggerObject

Event trigger configuration



46
47
48
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 46

def event_trigger
  @event_trigger
end

#event_trigger_draftObject

Draft event trigger configuration



49
50
51
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 49

def event_trigger_draft
  @event_trigger_draft
end

#executions_countObject

Number of times workflow has been executed



52
53
54
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 52

def executions_count
  @executions_count
end

#groupsObject

Permission groups (Admin only)



55
56
57
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 55

def groups
  @groups
end

#has_draftObject

Whether the workflow has unsaved draft changes



58
59
60
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 58

def has_draft
  @has_draft
end

#idObject

Unique identifier



19
20
21
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 19

def id
  @id
end

#is_managedObject

Whether this workflow is managed by the account and read-only



61
62
63
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 61

def is_managed
  @is_managed
end

#is_templateObject

Mark as template visible in library (Admin only)



64
65
66
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 64

def is_template
  @is_template
end

#keyObject

Unique key for the workflow



67
68
69
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 67

def key
  @key
end

#last_executed_atObject

Last executed at in specified timezone



70
71
72
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 70

def last_executed_at
  @last_executed_at
end

#last_executed_at_stringObject

Last executed at formatted as human-readable string



73
74
75
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 73

def last_executed_at_string
  @last_executed_at_string
end

#last_executed_at_utcObject

Last executed at in UTC



76
77
78
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 76

def last_executed_at_utc
  @last_executed_at_utc
end

#last_published_atObject

Last published at in specified timezone



79
80
81
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 79

def last_published_at
  @last_published_at
end

#last_published_at_stringObject

Last published at formatted as human-readable string



82
83
84
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 82

def last_published_at_string
  @last_published_at_string
end

#last_published_at_utcObject

Last published at in UTC



85
86
87
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 85

def last_published_at_utc
  @last_published_at_utc
end

#managed_byObject

Who manages this workflow (Admin only)



88
89
90
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 88

def managed_by
  @managed_by
end

#match_conditionsObject

Conditions for matching workflow execution



91
92
93
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 91

def match_conditions
  @match_conditions
end

#match_conditions_draftObject

Draft conditions for matching workflow execution



94
95
96
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 94

def match_conditions_draft
  @match_conditions_draft
end

#nameObject

Name of the workflow



97
98
99
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 97

def name
  @name
end

#objectObject

Object type identifier



100
101
102
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 100

def object
  @object
end

#onObject

Whether the workflow is enabled



103
104
105
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 103

def on
  @on
end

#statsObject

Workflow execution statistics



106
107
108
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 106

def stats
  @stats
end

#statusObject

Current status of the workflow



109
110
111
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 109

def status
  @status
end

#templateObject

Published workflow template layout



112
113
114
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 112

def template
  @template
end

#template_draftObject

Draft workflow template layout



115
116
117
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 115

def template_draft
  @template_draft
end

#trigger_conditionsObject

Conditions for triggering the workflow



118
119
120
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 118

def trigger_conditions
  @trigger_conditions
end

#trigger_conditions_draftObject

Draft conditions for triggering the workflow



121
122
123
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 121

def trigger_conditions_draft
  @trigger_conditions_draft
end

#updated_atObject

Updated at in specified timezone



124
125
126
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 124

def updated_at
  @updated_at
end

#updated_at_stringObject

Updated at formatted as human-readable string



127
128
129
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 127

def updated_at_string
  @updated_at_string
end

#updated_at_utcObject

Updated at in UTC



130
131
132
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 130

def updated_at_utc
  @updated_at_utc
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 573

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = EmbedWorkflow.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



199
200
201
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 199

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 155

def self.attribute_map
  {
    :'id' => :'id',
    :'account_template_id' => :'account_template_id',
    :'action_type_ids' => :'action_type_ids',
    :'actions_count' => :'actions_count',
    :'auto_clone_for_new_users' => :'auto_clone_for_new_users',
    :'created_at' => :'created_at',
    :'created_at_string' => :'created_at_string',
    :'created_at_utc' => :'created_at_utc',
    :'description' => :'description',
    :'event_trigger' => :'event_trigger',
    :'event_trigger_draft' => :'event_trigger_draft',
    :'executions_count' => :'executions_count',
    :'groups' => :'groups',
    :'has_draft' => :'has_draft',
    :'is_managed' => :'is_managed',
    :'is_template' => :'is_template',
    :'key' => :'key',
    :'last_executed_at' => :'last_executed_at',
    :'last_executed_at_string' => :'last_executed_at_string',
    :'last_executed_at_utc' => :'last_executed_at_utc',
    :'last_published_at' => :'last_published_at',
    :'last_published_at_string' => :'last_published_at_string',
    :'last_published_at_utc' => :'last_published_at_utc',
    :'managed_by' => :'managed_by',
    :'match_conditions' => :'match_conditions',
    :'match_conditions_draft' => :'match_conditions_draft',
    :'name' => :'name',
    :'object' => :'object',
    :'on' => :'on',
    :'stats' => :'stats',
    :'status' => :'status',
    :'template' => :'template',
    :'template_draft' => :'template_draft',
    :'trigger_conditions' => :'trigger_conditions',
    :'trigger_conditions_draft' => :'trigger_conditions_draft',
    :'updated_at' => :'updated_at',
    :'updated_at_string' => :'updated_at_string',
    :'updated_at_utc' => :'updated_at_utc'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 549

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 248

def self.openapi_nullable
  Set.new([
    :'account_template_id',
    :'created_at',
    :'created_at_string',
    :'created_at_utc',
    :'description',
    :'event_trigger',
    :'event_trigger_draft',
    :'last_executed_at',
    :'last_executed_at_string',
    :'last_executed_at_utc',
    :'last_published_at',
    :'last_published_at_string',
    :'last_published_at_utc',
    :'managed_by',
    :'match_conditions',
    :'match_conditions_draft',
    :'updated_at',
    :'updated_at_string',
    :'updated_at_utc'
  ])
end

.openapi_typesObject

Attribute type mapping.



204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 204

def self.openapi_types
  {
    :'id' => :'String',
    :'account_template_id' => :'String',
    :'action_type_ids' => :'Array<String>',
    :'actions_count' => :'Integer',
    :'auto_clone_for_new_users' => :'Boolean',
    :'created_at' => :'String',
    :'created_at_string' => :'String',
    :'created_at_utc' => :'String',
    :'description' => :'String',
    :'event_trigger' => :'Object',
    :'event_trigger_draft' => :'Object',
    :'executions_count' => :'Integer',
    :'groups' => :'Array<String>',
    :'has_draft' => :'Boolean',
    :'is_managed' => :'Boolean',
    :'is_template' => :'Boolean',
    :'key' => :'String',
    :'last_executed_at' => :'String',
    :'last_executed_at_string' => :'String',
    :'last_executed_at_utc' => :'String',
    :'last_published_at' => :'String',
    :'last_published_at_string' => :'String',
    :'last_published_at_utc' => :'String',
    :'managed_by' => :'String',
    :'match_conditions' => :'Object',
    :'match_conditions_draft' => :'Object',
    :'name' => :'String',
    :'object' => :'String',
    :'on' => :'Boolean',
    :'stats' => :'Hash<String, Object>',
    :'status' => :'String',
    :'template' => :'Object',
    :'template_draft' => :'Object',
    :'trigger_conditions' => :'Hash<String, Object>',
    :'trigger_conditions_draft' => :'Hash<String, Object>',
    :'updated_at' => :'String',
    :'updated_at_string' => :'String',
    :'updated_at_utc' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 491

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
       == o. &&
      action_type_ids == o.action_type_ids &&
      actions_count == o.actions_count &&
      auto_clone_for_new_users == o.auto_clone_for_new_users &&
      created_at == o.created_at &&
      created_at_string == o.created_at_string &&
      created_at_utc == o.created_at_utc &&
      description == o.description &&
      event_trigger == o.event_trigger &&
      event_trigger_draft == o.event_trigger_draft &&
      executions_count == o.executions_count &&
      groups == o.groups &&
      has_draft == o.has_draft &&
      is_managed == o.is_managed &&
      is_template == o.is_template &&
      key == o.key &&
      last_executed_at == o.last_executed_at &&
      last_executed_at_string == o.last_executed_at_string &&
      last_executed_at_utc == o.last_executed_at_utc &&
      last_published_at == o.last_published_at &&
      last_published_at_string == o.last_published_at_string &&
      last_published_at_utc == o.last_published_at_utc &&
      managed_by == o.managed_by &&
      match_conditions == o.match_conditions &&
      match_conditions_draft == o.match_conditions_draft &&
      name == o.name &&
      object == o.object &&
      on == o.on &&
      stats == o.stats &&
      status == o.status &&
      template == o.template &&
      template_draft == o.template_draft &&
      trigger_conditions == o.trigger_conditions &&
      trigger_conditions_draft == o.trigger_conditions_draft &&
      updated_at == o.updated_at &&
      updated_at_string == o.updated_at_string &&
      updated_at_utc == o.updated_at_utc
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



644
645
646
647
648
649
650
651
652
653
654
655
656
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 644

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


536
537
538
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 536

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



542
543
544
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 542

def hash
  [id, , action_type_ids, actions_count, auto_clone_for_new_users, created_at, created_at_string, created_at_utc, description, event_trigger, event_trigger_draft, executions_count, groups, has_draft, is_managed, is_template, key, last_executed_at, last_executed_at_string, last_executed_at_utc, last_published_at, last_published_at_string, last_published_at_utc, managed_by, match_conditions, match_conditions_draft, name, object, on, stats, status, template, template_draft, trigger_conditions, trigger_conditions_draft, updated_at, updated_at_string, updated_at_utc].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



452
453
454
455
456
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 452

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



620
621
622
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 620

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



626
627
628
629
630
631
632
633
634
635
636
637
638
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 626

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



614
615
616
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 614

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



460
461
462
463
464
465
466
467
# File 'lib/embed_workflow/models/create_workflow201_response.rb', line 460

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  managed_by_validator = EnumAttributeValidator.new('String', ["tenant", "account"])
  return false unless managed_by_validator.valid?(@managed_by)
  status_validator = EnumAttributeValidator.new('String', ["on", "off"])
  return false unless status_validator.valid?(@status)
  true
end