Class: EmbedWorkflow::ListActions200ResponseCollectionInner
- Inherits:
-
Object
- Object
- EmbedWorkflow::ListActions200ResponseCollectionInner
- Defined in:
- lib/embed_workflow/models/list_actions200_response_collection_inner.rb
Instance Attribute Summary collapse
-
#completed_at ⇒ Object
Completed at in specified timezone.
-
#completed_at_string ⇒ Object
Completed at formatted as human-readable string.
-
#completed_at_utc ⇒ Object
Completed at in UTC.
-
#execution_id ⇒ Object
ID of the execution this action belongs to.
-
#failed_at ⇒ Object
Failed at in specified timezone.
-
#failed_at_string ⇒ Object
Failed at formatted as human-readable string.
-
#failed_at_utc ⇒ Object
Failed at in UTC.
-
#failure_note ⇒ Object
Error message when action fails.
-
#hashid ⇒ Object
System-generated unique identifier.
-
#log ⇒ Object
Execution log details for the action.
-
#name ⇒ Object
Name of the action.
-
#node_id ⇒ Object
Node identifier associated with this action.
-
#object ⇒ Object
Object type identifier.
-
#run_at ⇒ Object
Run at in specified timezone.
-
#run_at_string ⇒ Object
Run at formatted as human-readable string.
-
#run_at_utc ⇒ Object
Run at in UTC.
-
#status ⇒ Object
Current status of the action.
-
#stopped_at ⇒ Object
Stopped at in specified timezone.
-
#stopped_at_string ⇒ Object
Stopped at formatted as human-readable string.
-
#stopped_at_utc ⇒ Object
Stopped at in UTC.
-
#uuid ⇒ Object
UUID identifier for the action.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListActions200ResponseCollectionInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ListActions200ResponseCollectionInner
Initializes the object
162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/embed_workflow/models/list_actions200_response_collection_inner.rb', line 162 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `EmbedWorkflow::ListActions200ResponseCollectionInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `EmbedWorkflow::ListActions200ResponseCollectionInner`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'hashid') self.hashid = attributes[:'hashid'] end if attributes.key?(:'completed_at') self.completed_at = attributes[:'completed_at'] end if attributes.key?(:'completed_at_string') self.completed_at_string = attributes[:'completed_at_string'] end if attributes.key?(:'completed_at_utc') self.completed_at_utc = attributes[:'completed_at_utc'] end if attributes.key?(:'execution_id') self.execution_id = attributes[:'execution_id'] end if attributes.key?(:'failed_at') self.failed_at = attributes[:'failed_at'] end if attributes.key?(:'failed_at_string') self.failed_at_string = attributes[:'failed_at_string'] end if attributes.key?(:'failed_at_utc') self.failed_at_utc = attributes[:'failed_at_utc'] end if attributes.key?(:'failure_note') self.failure_note = attributes[:'failure_note'] end if attributes.key?(:'log') self.log = attributes[:'log'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'node_id') self.node_id = attributes[:'node_id'] end if attributes.key?(:'object') self.object = attributes[:'object'] end if attributes.key?(:'run_at') self.run_at = attributes[:'run_at'] end if attributes.key?(:'run_at_string') self.run_at_string = attributes[:'run_at_string'] end if attributes.key?(:'run_at_utc') self.run_at_utc = attributes[:'run_at_utc'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'stopped_at') self.stopped_at = attributes[:'stopped_at'] end if attributes.key?(:'stopped_at_string') self.stopped_at_string = attributes[:'stopped_at_string'] end if attributes.key?(:'stopped_at_utc') self.stopped_at_utc = attributes[:'stopped_at_utc'] end if attributes.key?(:'uuid') self.uuid = attributes[:'uuid'] end end |
Instance Attribute Details
#completed_at ⇒ Object
Completed at in specified timezone
22 23 24 |
# File 'lib/embed_workflow/models/list_actions200_response_collection_inner.rb', line 22 def completed_at @completed_at end |
#completed_at_string ⇒ Object
Completed at formatted as human-readable string
25 26 27 |
# File 'lib/embed_workflow/models/list_actions200_response_collection_inner.rb', line 25 def completed_at_string @completed_at_string end |
#completed_at_utc ⇒ Object
Completed at in UTC
28 29 30 |
# File 'lib/embed_workflow/models/list_actions200_response_collection_inner.rb', line 28 def completed_at_utc @completed_at_utc end |
#execution_id ⇒ Object
ID of the execution this action belongs to
31 32 33 |
# File 'lib/embed_workflow/models/list_actions200_response_collection_inner.rb', line 31 def execution_id @execution_id end |
#failed_at ⇒ Object
Failed at in specified timezone
34 35 36 |
# File 'lib/embed_workflow/models/list_actions200_response_collection_inner.rb', line 34 def failed_at @failed_at end |
#failed_at_string ⇒ Object
Failed at formatted as human-readable string
37 38 39 |
# File 'lib/embed_workflow/models/list_actions200_response_collection_inner.rb', line 37 def failed_at_string @failed_at_string end |
#failed_at_utc ⇒ Object
Failed at in UTC
40 41 42 |
# File 'lib/embed_workflow/models/list_actions200_response_collection_inner.rb', line 40 def failed_at_utc @failed_at_utc end |
#failure_note ⇒ Object
Error message when action fails
43 44 45 |
# File 'lib/embed_workflow/models/list_actions200_response_collection_inner.rb', line 43 def failure_note @failure_note end |
#hashid ⇒ Object
System-generated unique identifier
19 20 21 |
# File 'lib/embed_workflow/models/list_actions200_response_collection_inner.rb', line 19 def hashid @hashid end |
#log ⇒ Object
Execution log details for the action
46 47 48 |
# File 'lib/embed_workflow/models/list_actions200_response_collection_inner.rb', line 46 def log @log end |
#name ⇒ Object
Name of the action
49 50 51 |
# File 'lib/embed_workflow/models/list_actions200_response_collection_inner.rb', line 49 def name @name end |
#node_id ⇒ Object
Node identifier associated with this action
52 53 54 |
# File 'lib/embed_workflow/models/list_actions200_response_collection_inner.rb', line 52 def node_id @node_id end |
#object ⇒ Object
Object type identifier
55 56 57 |
# File 'lib/embed_workflow/models/list_actions200_response_collection_inner.rb', line 55 def object @object end |
#run_at ⇒ Object
Run at in specified timezone
58 59 60 |
# File 'lib/embed_workflow/models/list_actions200_response_collection_inner.rb', line 58 def run_at @run_at end |
#run_at_string ⇒ Object
Run at formatted as human-readable string
61 62 63 |
# File 'lib/embed_workflow/models/list_actions200_response_collection_inner.rb', line 61 def run_at_string @run_at_string end |
#run_at_utc ⇒ Object
Run at in UTC
64 65 66 |
# File 'lib/embed_workflow/models/list_actions200_response_collection_inner.rb', line 64 def run_at_utc @run_at_utc end |
#status ⇒ Object
Current status of the action
67 68 69 |
# File 'lib/embed_workflow/models/list_actions200_response_collection_inner.rb', line 67 def status @status end |
#stopped_at ⇒ Object
Stopped at in specified timezone
70 71 72 |
# File 'lib/embed_workflow/models/list_actions200_response_collection_inner.rb', line 70 def stopped_at @stopped_at end |
#stopped_at_string ⇒ Object
Stopped at formatted as human-readable string
73 74 75 |
# File 'lib/embed_workflow/models/list_actions200_response_collection_inner.rb', line 73 def stopped_at_string @stopped_at_string end |
#stopped_at_utc ⇒ Object
Stopped at in UTC
76 77 78 |
# File 'lib/embed_workflow/models/list_actions200_response_collection_inner.rb', line 76 def stopped_at_utc @stopped_at_utc end |
#uuid ⇒ Object
UUID identifier for the action
79 80 81 |
# File 'lib/embed_workflow/models/list_actions200_response_collection_inner.rb', line 79 def uuid @uuid end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 |
# File 'lib/embed_workflow/models/list_actions200_response_collection_inner.rb', line 342 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = EmbedWorkflow.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
109 110 111 |
# File 'lib/embed_workflow/models/list_actions200_response_collection_inner.rb', line 109 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/embed_workflow/models/list_actions200_response_collection_inner.rb', line 82 def self.attribute_map { :'hashid' => :'hashid', :'completed_at' => :'completed_at', :'completed_at_string' => :'completed_at_string', :'completed_at_utc' => :'completed_at_utc', :'execution_id' => :'execution_id', :'failed_at' => :'failed_at', :'failed_at_string' => :'failed_at_string', :'failed_at_utc' => :'failed_at_utc', :'failure_note' => :'failure_note', :'log' => :'log', :'name' => :'name', :'node_id' => :'node_id', :'object' => :'object', :'run_at' => :'run_at', :'run_at_string' => :'run_at_string', :'run_at_utc' => :'run_at_utc', :'status' => :'status', :'stopped_at' => :'stopped_at', :'stopped_at_string' => :'stopped_at_string', :'stopped_at_utc' => :'stopped_at_utc', :'uuid' => :'uuid' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 |
# File 'lib/embed_workflow/models/list_actions200_response_collection_inner.rb', line 318 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/embed_workflow/models/list_actions200_response_collection_inner.rb', line 141 def self.openapi_nullable Set.new([ :'completed_at', :'completed_at_string', :'completed_at_utc', :'failed_at', :'failed_at_string', :'failed_at_utc', :'failure_note', :'log', :'run_at', :'run_at_string', :'run_at_utc', :'stopped_at', :'stopped_at_string', :'stopped_at_utc', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/embed_workflow/models/list_actions200_response_collection_inner.rb', line 114 def self.openapi_types { :'hashid' => :'String', :'completed_at' => :'String', :'completed_at_string' => :'String', :'completed_at_utc' => :'String', :'execution_id' => :'String', :'failed_at' => :'String', :'failed_at_string' => :'String', :'failed_at_utc' => :'String', :'failure_note' => :'String', :'log' => :'Object', :'name' => :'String', :'node_id' => :'String', :'object' => :'String', :'run_at' => :'String', :'run_at_string' => :'String', :'run_at_utc' => :'String', :'status' => :'String', :'stopped_at' => :'String', :'stopped_at_string' => :'String', :'stopped_at_utc' => :'String', :'uuid' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/embed_workflow/models/list_actions200_response_collection_inner.rb', line 277 def ==(o) return true if self.equal?(o) self.class == o.class && hashid == o.hashid && completed_at == o.completed_at && completed_at_string == o.completed_at_string && completed_at_utc == o.completed_at_utc && execution_id == o.execution_id && failed_at == o.failed_at && failed_at_string == o.failed_at_string && failed_at_utc == o.failed_at_utc && failure_note == o.failure_note && log == o.log && name == o.name && node_id == o.node_id && object == o.object && run_at == o.run_at && run_at_string == o.run_at_string && run_at_utc == o.run_at_utc && status == o.status && stopped_at == o.stopped_at && stopped_at_string == o.stopped_at_string && stopped_at_utc == o.stopped_at_utc && uuid == o.uuid end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
413 414 415 416 417 418 419 420 421 422 423 424 425 |
# File 'lib/embed_workflow/models/list_actions200_response_collection_inner.rb', line 413 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
305 306 307 |
# File 'lib/embed_workflow/models/list_actions200_response_collection_inner.rb', line 305 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
311 312 313 |
# File 'lib/embed_workflow/models/list_actions200_response_collection_inner.rb', line 311 def hash [hashid, completed_at, completed_at_string, completed_at_utc, execution_id, failed_at, failed_at_string, failed_at_utc, failure_note, log, name, node_id, object, run_at, run_at_string, run_at_utc, status, stopped_at, stopped_at_string, stopped_at_utc, uuid].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
262 263 264 265 266 |
# File 'lib/embed_workflow/models/list_actions200_response_collection_inner.rb', line 262 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
389 390 391 |
# File 'lib/embed_workflow/models/list_actions200_response_collection_inner.rb', line 389 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
395 396 397 398 399 400 401 402 403 404 405 406 407 |
# File 'lib/embed_workflow/models/list_actions200_response_collection_inner.rb', line 395 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
383 384 385 |
# File 'lib/embed_workflow/models/list_actions200_response_collection_inner.rb', line 383 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
270 271 272 273 |
# File 'lib/embed_workflow/models/list_actions200_response_collection_inner.rb', line 270 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |