Class: EmbedWorkflow::ListDataFields200ResponseCollectionInner

Inherits:
Object
  • Object
show all
Defined in:
lib/embed_workflow/models/list_data_fields200_response_collection_inner.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ListDataFields200ResponseCollectionInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/embed_workflow/models/list_data_fields200_response_collection_inner.rb', line 128

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `EmbedWorkflow::ListDataFields200ResponseCollectionInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `EmbedWorkflow::ListDataFields200ResponseCollectionInner`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'variable')
    self.variable = attributes[:'variable']
  end

  if attributes.key?(:'data_path')
    self.data_path = attributes[:'data_path']
  end

  if attributes.key?(:'display_label')
    self.display_label = attributes[:'display_label']
  end

  if attributes.key?(:'format')
    self.format = attributes[:'format']
  end

  if attributes.key?(:'groups')
    if (value = attributes[:'groups']).is_a?(Array)
      self.groups = value
    end
  end

  if attributes.key?(:'item_type')
    self.item_type = attributes[:'item_type']
  end

  if attributes.key?(:'iterator')
    self.iterator = attributes[:'iterator']
  end

  if attributes.key?(:'list_values_variable')
    self.list_values_variable = attributes[:'list_values_variable']
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  end

  if attributes.key?(:'required')
    self.required = attributes[:'required']
  end

  if attributes.key?(:'secret')
    self.secret = attributes[:'secret']
  end

  if attributes.key?(:'source')
    self.source = attributes[:'source']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'value')
    self.value = attributes[:'value']
  end

  if attributes.key?(:'children')
    if (value = attributes[:'children']).is_a?(Array)
      self.children = value
    end
  end
end

Instance Attribute Details

#childrenObject

Nested schema definitions. For arrays: single element defining item type. For objects: multiple elements defining properties



61
62
63
# File 'lib/embed_workflow/models/list_data_fields200_response_collection_inner.rb', line 61

def children
  @children
end

#data_pathObject

Path to the data within the structure



22
23
24
# File 'lib/embed_workflow/models/list_data_fields200_response_collection_inner.rb', line 22

def data_path
  @data_path
end

#display_labelObject

Display label for the data type



25
26
27
# File 'lib/embed_workflow/models/list_data_fields200_response_collection_inner.rb', line 25

def display_label
  @display_label
end

#formatObject

Format specification for the data type



28
29
30
# File 'lib/embed_workflow/models/list_data_fields200_response_collection_inner.rb', line 28

def format
  @format
end

#groupsObject

Permission groups for this data type



31
32
33
# File 'lib/embed_workflow/models/list_data_fields200_response_collection_inner.rb', line 31

def groups
  @groups
end

#item_typeObject

Type of each item in a List (e.g., ‘Object’, ‘String’, ‘Integer’)



34
35
36
# File 'lib/embed_workflow/models/list_data_fields200_response_collection_inner.rb', line 34

def item_type
  @item_type
end

#iteratorObject

Variable name for the current item when iterating over a List



37
38
39
# File 'lib/embed_workflow/models/list_data_fields200_response_collection_inner.rb', line 37

def iterator
  @iterator
end

#list_values_variableObject

Variable name for list values



40
41
42
# File 'lib/embed_workflow/models/list_data_fields200_response_collection_inner.rb', line 40

def list_values_variable
  @list_values_variable
end

#objectObject

Object type identifier



43
44
45
# File 'lib/embed_workflow/models/list_data_fields200_response_collection_inner.rb', line 43

def object
  @object
end

#requiredObject

Whether this data type is required



46
47
48
# File 'lib/embed_workflow/models/list_data_fields200_response_collection_inner.rb', line 46

def required
  @required
end

#secretObject

Whether this field value should be redacted in logs and API responses



49
50
51
# File 'lib/embed_workflow/models/list_data_fields200_response_collection_inner.rb', line 49

def secret
  @secret
end

#sourceObject

Source identifier for the data type



52
53
54
# File 'lib/embed_workflow/models/list_data_fields200_response_collection_inner.rb', line 52

def source
  @source
end

#typeObject

Data type identifier



55
56
57
# File 'lib/embed_workflow/models/list_data_fields200_response_collection_inner.rb', line 55

def type
  @type
end

#valueObject

Default or current value



58
59
60
# File 'lib/embed_workflow/models/list_data_fields200_response_collection_inner.rb', line 58

def value
  @value
end

#variableObject

Variable name used in templates



19
20
21
# File 'lib/embed_workflow/models/list_data_fields200_response_collection_inner.rb', line 19

def variable
  @variable
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
# File 'lib/embed_workflow/models/list_data_fields200_response_collection_inner.rb', line 282

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = EmbedWorkflow.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



85
86
87
# File 'lib/embed_workflow/models/list_data_fields200_response_collection_inner.rb', line 85

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/embed_workflow/models/list_data_fields200_response_collection_inner.rb', line 64

def self.attribute_map
  {
    :'variable' => :'variable',
    :'data_path' => :'data_path',
    :'display_label' => :'display_label',
    :'format' => :'format',
    :'groups' => :'groups',
    :'item_type' => :'item_type',
    :'iterator' => :'iterator',
    :'list_values_variable' => :'list_values_variable',
    :'object' => :'object',
    :'required' => :'required',
    :'secret' => :'secret',
    :'source' => :'source',
    :'type' => :'type',
    :'value' => :'value',
    :'children' => :'children'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/embed_workflow/models/list_data_fields200_response_collection_inner.rb', line 258

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/embed_workflow/models/list_data_fields200_response_collection_inner.rb', line 111

def self.openapi_nullable
  Set.new([
    :'data_path',
    :'format',
    :'groups',
    :'item_type',
    :'iterator',
    :'list_values_variable',
    :'secret',
    :'source',
    :'value',
    :'children'
  ])
end

.openapi_typesObject

Attribute type mapping.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/embed_workflow/models/list_data_fields200_response_collection_inner.rb', line 90

def self.openapi_types
  {
    :'variable' => :'String',
    :'data_path' => :'String',
    :'display_label' => :'String',
    :'format' => :'String',
    :'groups' => :'Array<String>',
    :'item_type' => :'String',
    :'iterator' => :'String',
    :'list_values_variable' => :'String',
    :'object' => :'String',
    :'required' => :'Boolean',
    :'secret' => :'Boolean',
    :'source' => :'String',
    :'type' => :'String',
    :'value' => :'String',
    :'children' => :'Array<Object>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/embed_workflow/models/list_data_fields200_response_collection_inner.rb', line 223

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      variable == o.variable &&
      data_path == o.data_path &&
      display_label == o.display_label &&
      format == o.format &&
      groups == o.groups &&
      item_type == o.item_type &&
      iterator == o.iterator &&
      list_values_variable == o.list_values_variable &&
      object == o.object &&
      required == o.required &&
      secret == o.secret &&
      source == o.source &&
      type == o.type &&
      value == o.value &&
      children == o.children
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



353
354
355
356
357
358
359
360
361
362
363
364
365
# File 'lib/embed_workflow/models/list_data_fields200_response_collection_inner.rb', line 353

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


245
246
247
# File 'lib/embed_workflow/models/list_data_fields200_response_collection_inner.rb', line 245

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



251
252
253
# File 'lib/embed_workflow/models/list_data_fields200_response_collection_inner.rb', line 251

def hash
  [variable, data_path, display_label, format, groups, item_type, iterator, list_values_variable, object, required, secret, source, type, value, children].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



208
209
210
211
212
# File 'lib/embed_workflow/models/list_data_fields200_response_collection_inner.rb', line 208

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



329
330
331
# File 'lib/embed_workflow/models/list_data_fields200_response_collection_inner.rb', line 329

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



335
336
337
338
339
340
341
342
343
344
345
346
347
# File 'lib/embed_workflow/models/list_data_fields200_response_collection_inner.rb', line 335

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



323
324
325
# File 'lib/embed_workflow/models/list_data_fields200_response_collection_inner.rb', line 323

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



216
217
218
219
# File 'lib/embed_workflow/models/list_data_fields200_response_collection_inner.rb', line 216

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end