Class: EmbedWorkflow::ListInstalledApps200ResponseCollectionInner

Inherits:
Object
  • Object
show all
Defined in:
lib/embed_workflow/models/list_installed_apps200_response_collection_inner.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ListInstalledApps200ResponseCollectionInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/embed_workflow/models/list_installed_apps200_response_collection_inner.rb', line 132

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `EmbedWorkflow::ListInstalledApps200ResponseCollectionInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `EmbedWorkflow::ListInstalledApps200ResponseCollectionInner`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'app_identifier')
    self.app_identifier = attributes[:'app_identifier']
  end

  if attributes.key?(:'app_version')
    self.app_version = attributes[:'app_version']
  end

  if attributes.key?(:'available_version')
    self.available_version = attributes[:'available_version']
  end

  if attributes.key?(:'groups')
    if (value = attributes[:'groups']).is_a?(Array)
      self.groups = value
    end
  end

  if attributes.key?(:'icon')
    self.icon = attributes[:'icon']
  end

  if attributes.key?(:'last_used_at')
    self.last_used_at = attributes[:'last_used_at']
  end

  if attributes.key?(:'last_used_at_string')
    self.last_used_at_string = attributes[:'last_used_at_string']
  end

  if attributes.key?(:'last_used_at_utc')
    self.last_used_at_utc = attributes[:'last_used_at_utc']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'object')
    self.object = attributes[:'object']
  end

  if attributes.key?(:'previous_version')
    self.previous_version = attributes[:'previous_version']
  end

  if attributes.key?(:'upgrade_available')
    self.upgrade_available = attributes[:'upgrade_available']
  end

  if attributes.key?(:'upgraded_at')
    self.upgraded_at = attributes[:'upgraded_at']
  end

  if attributes.key?(:'upgraded_at_string')
    self.upgraded_at_string = attributes[:'upgraded_at_string']
  end

  if attributes.key?(:'upgraded_at_utc')
    self.upgraded_at_utc = attributes[:'upgraded_at_utc']
  end
end

Instance Attribute Details

#app_identifierObject

Unique identifier for the app



22
23
24
# File 'lib/embed_workflow/models/list_installed_apps200_response_collection_inner.rb', line 22

def app_identifier
  @app_identifier
end

#app_versionObject

Currently installed version of the app



25
26
27
# File 'lib/embed_workflow/models/list_installed_apps200_response_collection_inner.rb', line 25

def app_version
  @app_version
end

#available_versionObject

Latest available version of the app



28
29
30
# File 'lib/embed_workflow/models/list_installed_apps200_response_collection_inner.rb', line 28

def available_version
  @available_version
end

#groupsObject

Permission groups that can access this app



31
32
33
# File 'lib/embed_workflow/models/list_installed_apps200_response_collection_inner.rb', line 31

def groups
  @groups
end

#iconObject

Icon configuration for the installed app



34
35
36
# File 'lib/embed_workflow/models/list_installed_apps200_response_collection_inner.rb', line 34

def icon
  @icon
end

#idObject

System-generated unique identifier



19
20
21
# File 'lib/embed_workflow/models/list_installed_apps200_response_collection_inner.rb', line 19

def id
  @id
end

#last_used_atObject

Last used at in specified timezone



37
38
39
# File 'lib/embed_workflow/models/list_installed_apps200_response_collection_inner.rb', line 37

def last_used_at
  @last_used_at
end

#last_used_at_stringObject

Last used at formatted as human-readable string



40
41
42
# File 'lib/embed_workflow/models/list_installed_apps200_response_collection_inner.rb', line 40

def last_used_at_string
  @last_used_at_string
end

#last_used_at_utcObject

Last used at in UTC



43
44
45
# File 'lib/embed_workflow/models/list_installed_apps200_response_collection_inner.rb', line 43

def last_used_at_utc
  @last_used_at_utc
end

#nameObject

Display name of the installed app



46
47
48
# File 'lib/embed_workflow/models/list_installed_apps200_response_collection_inner.rb', line 46

def name
  @name
end

#objectObject

Object type identifier



49
50
51
# File 'lib/embed_workflow/models/list_installed_apps200_response_collection_inner.rb', line 49

def object
  @object
end

#previous_versionObject

Previously installed version of the app



52
53
54
# File 'lib/embed_workflow/models/list_installed_apps200_response_collection_inner.rb', line 52

def previous_version
  @previous_version
end

#upgrade_availableObject

Whether an upgrade is available for this app



55
56
57
# File 'lib/embed_workflow/models/list_installed_apps200_response_collection_inner.rb', line 55

def upgrade_available
  @upgrade_available
end

#upgraded_atObject

Upgraded at in specified timezone



58
59
60
# File 'lib/embed_workflow/models/list_installed_apps200_response_collection_inner.rb', line 58

def upgraded_at
  @upgraded_at
end

#upgraded_at_stringObject

Upgraded at formatted as human-readable string



61
62
63
# File 'lib/embed_workflow/models/list_installed_apps200_response_collection_inner.rb', line 61

def upgraded_at_string
  @upgraded_at_string
end

#upgraded_at_utcObject

Upgraded at in UTC



64
65
66
# File 'lib/embed_workflow/models/list_installed_apps200_response_collection_inner.rb', line 64

def upgraded_at_utc
  @upgraded_at_utc
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
# File 'lib/embed_workflow/models/list_installed_apps200_response_collection_inner.rb', line 289

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = EmbedWorkflow.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



89
90
91
# File 'lib/embed_workflow/models/list_installed_apps200_response_collection_inner.rb', line 89

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/embed_workflow/models/list_installed_apps200_response_collection_inner.rb', line 67

def self.attribute_map
  {
    :'id' => :'id',
    :'app_identifier' => :'app_identifier',
    :'app_version' => :'app_version',
    :'available_version' => :'available_version',
    :'groups' => :'groups',
    :'icon' => :'icon',
    :'last_used_at' => :'last_used_at',
    :'last_used_at_string' => :'last_used_at_string',
    :'last_used_at_utc' => :'last_used_at_utc',
    :'name' => :'name',
    :'object' => :'object',
    :'previous_version' => :'previous_version',
    :'upgrade_available' => :'upgrade_available',
    :'upgraded_at' => :'upgraded_at',
    :'upgraded_at_string' => :'upgraded_at_string',
    :'upgraded_at_utc' => :'upgraded_at_utc'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/embed_workflow/models/list_installed_apps200_response_collection_inner.rb', line 265

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/embed_workflow/models/list_installed_apps200_response_collection_inner.rb', line 116

def self.openapi_nullable
  Set.new([
    :'available_version',
    :'icon',
    :'last_used_at',
    :'last_used_at_string',
    :'last_used_at_utc',
    :'previous_version',
    :'upgraded_at',
    :'upgraded_at_string',
    :'upgraded_at_utc'
  ])
end

.openapi_typesObject

Attribute type mapping.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/embed_workflow/models/list_installed_apps200_response_collection_inner.rb', line 94

def self.openapi_types
  {
    :'id' => :'String',
    :'app_identifier' => :'String',
    :'app_version' => :'String',
    :'available_version' => :'String',
    :'groups' => :'Array<String>',
    :'icon' => :'Object',
    :'last_used_at' => :'String',
    :'last_used_at_string' => :'String',
    :'last_used_at_utc' => :'String',
    :'name' => :'String',
    :'object' => :'String',
    :'previous_version' => :'String',
    :'upgrade_available' => :'Boolean',
    :'upgraded_at' => :'String',
    :'upgraded_at_string' => :'String',
    :'upgraded_at_utc' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/embed_workflow/models/list_installed_apps200_response_collection_inner.rb', line 229

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      app_identifier == o.app_identifier &&
      app_version == o.app_version &&
      available_version == o.available_version &&
      groups == o.groups &&
      icon == o.icon &&
      last_used_at == o.last_used_at &&
      last_used_at_string == o.last_used_at_string &&
      last_used_at_utc == o.last_used_at_utc &&
      name == o.name &&
      object == o.object &&
      previous_version == o.previous_version &&
      upgrade_available == o.upgrade_available &&
      upgraded_at == o.upgraded_at &&
      upgraded_at_string == o.upgraded_at_string &&
      upgraded_at_utc == o.upgraded_at_utc
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



360
361
362
363
364
365
366
367
368
369
370
371
372
# File 'lib/embed_workflow/models/list_installed_apps200_response_collection_inner.rb', line 360

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


252
253
254
# File 'lib/embed_workflow/models/list_installed_apps200_response_collection_inner.rb', line 252

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



258
259
260
# File 'lib/embed_workflow/models/list_installed_apps200_response_collection_inner.rb', line 258

def hash
  [id, app_identifier, app_version, available_version, groups, icon, last_used_at, last_used_at_string, last_used_at_utc, name, object, previous_version, upgrade_available, upgraded_at, upgraded_at_string, upgraded_at_utc].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



214
215
216
217
218
# File 'lib/embed_workflow/models/list_installed_apps200_response_collection_inner.rb', line 214

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



336
337
338
# File 'lib/embed_workflow/models/list_installed_apps200_response_collection_inner.rb', line 336

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



342
343
344
345
346
347
348
349
350
351
352
353
354
# File 'lib/embed_workflow/models/list_installed_apps200_response_collection_inner.rb', line 342

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



330
331
332
# File 'lib/embed_workflow/models/list_installed_apps200_response_collection_inner.rb', line 330

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



222
223
224
225
# File 'lib/embed_workflow/models/list_installed_apps200_response_collection_inner.rb', line 222

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end