Class: EmbedWorkflow::ListTriggers200ResponseCollectionInner
- Inherits:
-
Object
- Object
- EmbedWorkflow::ListTriggers200ResponseCollectionInner
- Defined in:
- lib/embed_workflow/models/list_triggers200_response_collection_inner.rb
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Created at in specified timezone.
-
#created_at_string ⇒ Object
Created at formatted as human-readable string.
-
#created_at_utc ⇒ Object
Created at in UTC.
-
#data_input_schema ⇒ Object
Data input schema for the trigger.
-
#description ⇒ Object
Short description for the trigger.
-
#event ⇒ Object
Event type that activates this trigger.
-
#groups ⇒ Object
Permission groups for this trigger.
-
#hook_id ⇒ Object
Hook identifier for the trigger.
-
#icon ⇒ Object
Icon configuration for the trigger.
-
#id ⇒ Object
System-generated unique identifier.
-
#last_triggered_at ⇒ Object
Last triggered at in specified timezone.
-
#last_triggered_at_string ⇒ Object
Last triggered at formatted as human-readable string.
-
#last_triggered_at_utc ⇒ Object
Last triggered at in UTC.
-
#object ⇒ Object
Object type identifier.
-
#on ⇒ Object
Whether the trigger is enabled.
-
#processed_count ⇒ Object
Number of times this trigger has been processed.
-
#title ⇒ Object
Display title for the trigger.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListTriggers200ResponseCollectionInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ListTriggers200ResponseCollectionInner
Initializes the object
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/embed_workflow/models/list_triggers200_response_collection_inner.rb', line 136 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `EmbedWorkflow::ListTriggers200ResponseCollectionInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `EmbedWorkflow::ListTriggers200ResponseCollectionInner`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'created_at_string') self.created_at_string = attributes[:'created_at_string'] end if attributes.key?(:'created_at_utc') self.created_at_utc = attributes[:'created_at_utc'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'event') self.event = attributes[:'event'] end if attributes.key?(:'groups') if (value = attributes[:'groups']).is_a?(Array) self.groups = value end end if attributes.key?(:'hook_id') self.hook_id = attributes[:'hook_id'] end if attributes.key?(:'icon') self.icon = attributes[:'icon'] end if attributes.key?(:'last_triggered_at') self.last_triggered_at = attributes[:'last_triggered_at'] end if attributes.key?(:'last_triggered_at_string') self.last_triggered_at_string = attributes[:'last_triggered_at_string'] end if attributes.key?(:'last_triggered_at_utc') self.last_triggered_at_utc = attributes[:'last_triggered_at_utc'] end if attributes.key?(:'object') self.object = attributes[:'object'] end if attributes.key?(:'on') self.on = attributes[:'on'] end if attributes.key?(:'processed_count') self.processed_count = attributes[:'processed_count'] end if attributes.key?(:'title') self.title = attributes[:'title'] end if attributes.key?(:'data_input_schema') if (value = attributes[:'data_input_schema']).is_a?(Array) self.data_input_schema = value end end end |
Instance Attribute Details
#created_at ⇒ Object
Created at in specified timezone
22 23 24 |
# File 'lib/embed_workflow/models/list_triggers200_response_collection_inner.rb', line 22 def created_at @created_at end |
#created_at_string ⇒ Object
Created at formatted as human-readable string
25 26 27 |
# File 'lib/embed_workflow/models/list_triggers200_response_collection_inner.rb', line 25 def created_at_string @created_at_string end |
#created_at_utc ⇒ Object
Created at in UTC
28 29 30 |
# File 'lib/embed_workflow/models/list_triggers200_response_collection_inner.rb', line 28 def created_at_utc @created_at_utc end |
#data_input_schema ⇒ Object
Data input schema for the trigger
67 68 69 |
# File 'lib/embed_workflow/models/list_triggers200_response_collection_inner.rb', line 67 def data_input_schema @data_input_schema end |
#description ⇒ Object
Short description for the trigger
31 32 33 |
# File 'lib/embed_workflow/models/list_triggers200_response_collection_inner.rb', line 31 def description @description end |
#event ⇒ Object
Event type that activates this trigger
34 35 36 |
# File 'lib/embed_workflow/models/list_triggers200_response_collection_inner.rb', line 34 def event @event end |
#groups ⇒ Object
Permission groups for this trigger
37 38 39 |
# File 'lib/embed_workflow/models/list_triggers200_response_collection_inner.rb', line 37 def groups @groups end |
#hook_id ⇒ Object
Hook identifier for the trigger
40 41 42 |
# File 'lib/embed_workflow/models/list_triggers200_response_collection_inner.rb', line 40 def hook_id @hook_id end |
#icon ⇒ Object
Icon configuration for the trigger
43 44 45 |
# File 'lib/embed_workflow/models/list_triggers200_response_collection_inner.rb', line 43 def icon @icon end |
#id ⇒ Object
System-generated unique identifier
19 20 21 |
# File 'lib/embed_workflow/models/list_triggers200_response_collection_inner.rb', line 19 def id @id end |
#last_triggered_at ⇒ Object
Last triggered at in specified timezone
46 47 48 |
# File 'lib/embed_workflow/models/list_triggers200_response_collection_inner.rb', line 46 def last_triggered_at @last_triggered_at end |
#last_triggered_at_string ⇒ Object
Last triggered at formatted as human-readable string
49 50 51 |
# File 'lib/embed_workflow/models/list_triggers200_response_collection_inner.rb', line 49 def last_triggered_at_string @last_triggered_at_string end |
#last_triggered_at_utc ⇒ Object
Last triggered at in UTC
52 53 54 |
# File 'lib/embed_workflow/models/list_triggers200_response_collection_inner.rb', line 52 def last_triggered_at_utc @last_triggered_at_utc end |
#object ⇒ Object
Object type identifier
55 56 57 |
# File 'lib/embed_workflow/models/list_triggers200_response_collection_inner.rb', line 55 def object @object end |
#on ⇒ Object
Whether the trigger is enabled
58 59 60 |
# File 'lib/embed_workflow/models/list_triggers200_response_collection_inner.rb', line 58 def on @on end |
#processed_count ⇒ Object
Number of times this trigger has been processed
61 62 63 |
# File 'lib/embed_workflow/models/list_triggers200_response_collection_inner.rb', line 61 def processed_count @processed_count end |
#title ⇒ Object
Display title for the trigger
64 65 66 |
# File 'lib/embed_workflow/models/list_triggers200_response_collection_inner.rb', line 64 def title @title end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/embed_workflow/models/list_triggers200_response_collection_inner.rb', line 300 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = EmbedWorkflow.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
93 94 95 |
# File 'lib/embed_workflow/models/list_triggers200_response_collection_inner.rb', line 93 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/embed_workflow/models/list_triggers200_response_collection_inner.rb', line 70 def self.attribute_map { :'id' => :'id', :'created_at' => :'created_at', :'created_at_string' => :'created_at_string', :'created_at_utc' => :'created_at_utc', :'description' => :'description', :'event' => :'event', :'groups' => :'groups', :'hook_id' => :'hook_id', :'icon' => :'icon', :'last_triggered_at' => :'last_triggered_at', :'last_triggered_at_string' => :'last_triggered_at_string', :'last_triggered_at_utc' => :'last_triggered_at_utc', :'object' => :'object', :'on' => :'on', :'processed_count' => :'processed_count', :'title' => :'title', :'data_input_schema' => :'data_input_schema' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/embed_workflow/models/list_triggers200_response_collection_inner.rb', line 276 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/embed_workflow/models/list_triggers200_response_collection_inner.rb', line 121 def self.openapi_nullable Set.new([ :'created_at', :'created_at_string', :'created_at_utc', :'description', :'icon', :'last_triggered_at', :'last_triggered_at_string', :'last_triggered_at_utc', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/embed_workflow/models/list_triggers200_response_collection_inner.rb', line 98 def self.openapi_types { :'id' => :'String', :'created_at' => :'String', :'created_at_string' => :'String', :'created_at_utc' => :'String', :'description' => :'String', :'event' => :'String', :'groups' => :'Array<String>', :'hook_id' => :'String', :'icon' => :'Object', :'last_triggered_at' => :'String', :'last_triggered_at_string' => :'String', :'last_triggered_at_utc' => :'String', :'object' => :'String', :'on' => :'Boolean', :'processed_count' => :'Integer', :'title' => :'String', :'data_input_schema' => :'Array<Object>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/embed_workflow/models/list_triggers200_response_collection_inner.rb', line 239 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && created_at == o.created_at && created_at_string == o.created_at_string && created_at_utc == o.created_at_utc && description == o.description && event == o.event && groups == o.groups && hook_id == o.hook_id && icon == o.icon && last_triggered_at == o.last_triggered_at && last_triggered_at_string == o.last_triggered_at_string && last_triggered_at_utc == o.last_triggered_at_utc && object == o.object && on == o.on && processed_count == o.processed_count && title == o.title && data_input_schema == o.data_input_schema end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/embed_workflow/models/list_triggers200_response_collection_inner.rb', line 371 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
263 264 265 |
# File 'lib/embed_workflow/models/list_triggers200_response_collection_inner.rb', line 263 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
269 270 271 |
# File 'lib/embed_workflow/models/list_triggers200_response_collection_inner.rb', line 269 def hash [id, created_at, created_at_string, created_at_utc, description, event, groups, hook_id, icon, last_triggered_at, last_triggered_at_string, last_triggered_at_utc, object, on, processed_count, title, data_input_schema].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
224 225 226 227 228 |
# File 'lib/embed_workflow/models/list_triggers200_response_collection_inner.rb', line 224 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
347 348 349 |
# File 'lib/embed_workflow/models/list_triggers200_response_collection_inner.rb', line 347 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'lib/embed_workflow/models/list_triggers200_response_collection_inner.rb', line 353 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
341 342 343 |
# File 'lib/embed_workflow/models/list_triggers200_response_collection_inner.rb', line 341 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
232 233 234 235 |
# File 'lib/embed_workflow/models/list_triggers200_response_collection_inner.rb', line 232 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |