Class: EmbedWorkflow::RetrieveExecution200Response
- Inherits:
-
Object
- Object
- EmbedWorkflow::RetrieveExecution200Response
- Defined in:
- lib/embed_workflow/models/retrieve_execution200_response.rb
Instance Attribute Summary collapse
-
#actions_count ⇒ Object
Total number of actions in the execution.
-
#completed_actions_count ⇒ Object
Number of completed actions.
-
#created_at ⇒ Object
Created at in specified timezone.
-
#created_at_string ⇒ Object
Created at formatted as human-readable string.
-
#created_at_utc ⇒ Object
Created at in UTC.
-
#execution_data ⇒ Object
Data context for the execution.
-
#failed_actions_count ⇒ Object
Number of failed actions.
-
#hashid ⇒ Object
System-generated unique identifier.
-
#id ⇒ Object
System-generated unique identifier.
-
#idle_actions_count ⇒ Object
Number of idle actions.
-
#key ⇒ Object
Unique key for the execution.
-
#log ⇒ Object
Execution log details.
-
#name ⇒ Object
Name of the execution.
-
#object ⇒ Object
Object type identifier.
-
#running_actions_count ⇒ Object
Number of currently running actions.
-
#stats ⇒ Object
Execution statistics.
-
#status ⇒ Object
Current status of the execution.
-
#stopped_actions_count ⇒ Object
Number of stopped actions.
-
#template ⇒ Object
Template layout for the execution.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RetrieveExecution200Response
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ RetrieveExecution200Response
Initializes the object
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/embed_workflow/models/retrieve_execution200_response.rb', line 144 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `EmbedWorkflow::RetrieveExecution200Response` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `EmbedWorkflow::RetrieveExecution200Response`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'hashid') self.hashid = attributes[:'hashid'] end if attributes.key?(:'actions_count') self.actions_count = attributes[:'actions_count'] end if attributes.key?(:'completed_actions_count') self.completed_actions_count = attributes[:'completed_actions_count'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'created_at_string') self.created_at_string = attributes[:'created_at_string'] end if attributes.key?(:'created_at_utc') self.created_at_utc = attributes[:'created_at_utc'] end if attributes.key?(:'execution_data') if (value = attributes[:'execution_data']).is_a?(Hash) self.execution_data = value end end if attributes.key?(:'failed_actions_count') self.failed_actions_count = attributes[:'failed_actions_count'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'idle_actions_count') self.idle_actions_count = attributes[:'idle_actions_count'] end if attributes.key?(:'key') self.key = attributes[:'key'] end if attributes.key?(:'log') self.log = attributes[:'log'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'object') self.object = attributes[:'object'] end if attributes.key?(:'running_actions_count') self.running_actions_count = attributes[:'running_actions_count'] end if attributes.key?(:'stats') if (value = attributes[:'stats']).is_a?(Hash) self.stats = value end end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'stopped_actions_count') self.stopped_actions_count = attributes[:'stopped_actions_count'] end if attributes.key?(:'template') self.template = attributes[:'template'] end end |
Instance Attribute Details
#actions_count ⇒ Object
Total number of actions in the execution
22 23 24 |
# File 'lib/embed_workflow/models/retrieve_execution200_response.rb', line 22 def actions_count @actions_count end |
#completed_actions_count ⇒ Object
Number of completed actions
25 26 27 |
# File 'lib/embed_workflow/models/retrieve_execution200_response.rb', line 25 def completed_actions_count @completed_actions_count end |
#created_at ⇒ Object
Created at in specified timezone
28 29 30 |
# File 'lib/embed_workflow/models/retrieve_execution200_response.rb', line 28 def created_at @created_at end |
#created_at_string ⇒ Object
Created at formatted as human-readable string
31 32 33 |
# File 'lib/embed_workflow/models/retrieve_execution200_response.rb', line 31 def created_at_string @created_at_string end |
#created_at_utc ⇒ Object
Created at in UTC
34 35 36 |
# File 'lib/embed_workflow/models/retrieve_execution200_response.rb', line 34 def created_at_utc @created_at_utc end |
#execution_data ⇒ Object
Data context for the execution
37 38 39 |
# File 'lib/embed_workflow/models/retrieve_execution200_response.rb', line 37 def execution_data @execution_data end |
#failed_actions_count ⇒ Object
Number of failed actions
40 41 42 |
# File 'lib/embed_workflow/models/retrieve_execution200_response.rb', line 40 def failed_actions_count @failed_actions_count end |
#hashid ⇒ Object
System-generated unique identifier
19 20 21 |
# File 'lib/embed_workflow/models/retrieve_execution200_response.rb', line 19 def hashid @hashid end |
#id ⇒ Object
System-generated unique identifier
43 44 45 |
# File 'lib/embed_workflow/models/retrieve_execution200_response.rb', line 43 def id @id end |
#idle_actions_count ⇒ Object
Number of idle actions
46 47 48 |
# File 'lib/embed_workflow/models/retrieve_execution200_response.rb', line 46 def idle_actions_count @idle_actions_count end |
#key ⇒ Object
Unique key for the execution
49 50 51 |
# File 'lib/embed_workflow/models/retrieve_execution200_response.rb', line 49 def key @key end |
#log ⇒ Object
Execution log details
52 53 54 |
# File 'lib/embed_workflow/models/retrieve_execution200_response.rb', line 52 def log @log end |
#name ⇒ Object
Name of the execution
55 56 57 |
# File 'lib/embed_workflow/models/retrieve_execution200_response.rb', line 55 def name @name end |
#object ⇒ Object
Object type identifier
58 59 60 |
# File 'lib/embed_workflow/models/retrieve_execution200_response.rb', line 58 def object @object end |
#running_actions_count ⇒ Object
Number of currently running actions
61 62 63 |
# File 'lib/embed_workflow/models/retrieve_execution200_response.rb', line 61 def running_actions_count @running_actions_count end |
#stats ⇒ Object
Execution statistics
64 65 66 |
# File 'lib/embed_workflow/models/retrieve_execution200_response.rb', line 64 def stats @stats end |
#status ⇒ Object
Current status of the execution
67 68 69 |
# File 'lib/embed_workflow/models/retrieve_execution200_response.rb', line 67 def status @status end |
#stopped_actions_count ⇒ Object
Number of stopped actions
70 71 72 |
# File 'lib/embed_workflow/models/retrieve_execution200_response.rb', line 70 def stopped_actions_count @stopped_actions_count end |
#template ⇒ Object
Template layout for the execution
73 74 75 |
# File 'lib/embed_workflow/models/retrieve_execution200_response.rb', line 73 def template @template end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 |
# File 'lib/embed_workflow/models/retrieve_execution200_response.rb', line 318 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = EmbedWorkflow.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
101 102 103 |
# File 'lib/embed_workflow/models/retrieve_execution200_response.rb', line 101 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/embed_workflow/models/retrieve_execution200_response.rb', line 76 def self.attribute_map { :'hashid' => :'hashid', :'actions_count' => :'actions_count', :'completed_actions_count' => :'completed_actions_count', :'created_at' => :'created_at', :'created_at_string' => :'created_at_string', :'created_at_utc' => :'created_at_utc', :'execution_data' => :'execution_data', :'failed_actions_count' => :'failed_actions_count', :'id' => :'id', :'idle_actions_count' => :'idle_actions_count', :'key' => :'key', :'log' => :'log', :'name' => :'name', :'object' => :'object', :'running_actions_count' => :'running_actions_count', :'stats' => :'stats', :'status' => :'status', :'stopped_actions_count' => :'stopped_actions_count', :'template' => :'template' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'lib/embed_workflow/models/retrieve_execution200_response.rb', line 294 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
131 132 133 134 135 136 137 138 139 140 |
# File 'lib/embed_workflow/models/retrieve_execution200_response.rb', line 131 def self.openapi_nullable Set.new([ :'actions_count', :'created_at', :'created_at_string', :'created_at_utc', :'execution_data', :'log', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/embed_workflow/models/retrieve_execution200_response.rb', line 106 def self.openapi_types { :'hashid' => :'String', :'actions_count' => :'Integer', :'completed_actions_count' => :'Integer', :'created_at' => :'String', :'created_at_string' => :'String', :'created_at_utc' => :'String', :'execution_data' => :'Hash<String, Object>', :'failed_actions_count' => :'Integer', :'id' => :'String', :'idle_actions_count' => :'Integer', :'key' => :'String', :'log' => :'Object', :'name' => :'String', :'object' => :'String', :'running_actions_count' => :'Integer', :'stats' => :'Hash<String, Object>', :'status' => :'String', :'stopped_actions_count' => :'Integer', :'template' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/embed_workflow/models/retrieve_execution200_response.rb', line 255 def ==(o) return true if self.equal?(o) self.class == o.class && hashid == o.hashid && actions_count == o.actions_count && completed_actions_count == o.completed_actions_count && created_at == o.created_at && created_at_string == o.created_at_string && created_at_utc == o.created_at_utc && execution_data == o.execution_data && failed_actions_count == o.failed_actions_count && id == o.id && idle_actions_count == o.idle_actions_count && key == o.key && log == o.log && name == o.name && object == o.object && running_actions_count == o.running_actions_count && stats == o.stats && status == o.status && stopped_actions_count == o.stopped_actions_count && template == o.template end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
389 390 391 392 393 394 395 396 397 398 399 400 401 |
# File 'lib/embed_workflow/models/retrieve_execution200_response.rb', line 389 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
281 282 283 |
# File 'lib/embed_workflow/models/retrieve_execution200_response.rb', line 281 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
287 288 289 |
# File 'lib/embed_workflow/models/retrieve_execution200_response.rb', line 287 def hash [hashid, actions_count, completed_actions_count, created_at, created_at_string, created_at_utc, execution_data, failed_actions_count, id, idle_actions_count, key, log, name, object, running_actions_count, stats, status, stopped_actions_count, template].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
240 241 242 243 244 |
# File 'lib/embed_workflow/models/retrieve_execution200_response.rb', line 240 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
365 366 367 |
# File 'lib/embed_workflow/models/retrieve_execution200_response.rb', line 365 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/embed_workflow/models/retrieve_execution200_response.rb', line 371 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
359 360 361 |
# File 'lib/embed_workflow/models/retrieve_execution200_response.rb', line 359 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
248 249 250 251 |
# File 'lib/embed_workflow/models/retrieve_execution200_response.rb', line 248 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |