Class: EmbedWorkflow::UpdateWorkflowRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/embed_workflow/models/update_workflow_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdateWorkflowRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/embed_workflow/models/update_workflow_request.rb', line 97

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `EmbedWorkflow::UpdateWorkflowRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `EmbedWorkflow::UpdateWorkflowRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  end

  if attributes.key?(:'auto_clone_for_new_users')
    self.auto_clone_for_new_users = attributes[:'auto_clone_for_new_users']
  else
    self.auto_clone_for_new_users = false
  end

  if attributes.key?(:'is_template')
    self.is_template = attributes[:'is_template']
  else
    self.is_template = false
  end

  if attributes.key?(:'on')
    self.on = attributes[:'on']
  else
    self.on = true
  end

  if attributes.key?(:'details')
    self.details = attributes[:'details']
  end

  if attributes.key?(:'template_draft')
    self.template_draft = attributes[:'template_draft']
  end

  if attributes.key?(:'trigger_conditions_draft')
    self.trigger_conditions_draft = attributes[:'trigger_conditions_draft']
  end

  if attributes.key?(:'event_trigger_draft')
    self.event_trigger_draft = attributes[:'event_trigger_draft']
  end

  if attributes.key?(:'match_conditions_draft')
    self.match_conditions_draft = attributes[:'match_conditions_draft']
  end

  if attributes.key?(:'groups')
    if (value = attributes[:'groups']).is_a?(Array)
      self.groups = value
    end
  end
end

Instance Attribute Details

#auto_clone_for_new_usersObject

Mark workflow as default template. When true, new users will automatically receive a clone of this workflow (Admin only)



25
26
27
# File 'lib/embed_workflow/models/update_workflow_request.rb', line 25

def auto_clone_for_new_users
  @auto_clone_for_new_users
end

#detailsObject

Description of the resource



34
35
36
# File 'lib/embed_workflow/models/update_workflow_request.rb', line 34

def details
  @details
end

#event_trigger_draftObject

The trigger’s key



42
43
44
# File 'lib/embed_workflow/models/update_workflow_request.rb', line 42

def event_trigger_draft
  @event_trigger_draft
end

#groupsObject

User permission groups. Only available to users with admin role.



48
49
50
# File 'lib/embed_workflow/models/update_workflow_request.rb', line 48

def groups
  @groups
end

#is_templateObject

Mark workflow as a template. When true, new users will see this in a library of templates (Admin only)



28
29
30
# File 'lib/embed_workflow/models/update_workflow_request.rb', line 28

def is_template
  @is_template
end

#keyObject

Client-provided unique identifier



22
23
24
# File 'lib/embed_workflow/models/update_workflow_request.rb', line 22

def key
  @key
end

#match_conditions_draftObject

Whether all or any of the trigger conditions must match



45
46
47
# File 'lib/embed_workflow/models/update_workflow_request.rb', line 45

def match_conditions_draft
  @match_conditions_draft
end

#nameObject

Name of resource



19
20
21
# File 'lib/embed_workflow/models/update_workflow_request.rb', line 19

def name
  @name
end

#onObject

Enable or disable the resource.



31
32
33
# File 'lib/embed_workflow/models/update_workflow_request.rb', line 31

def on
  @on
end

#template_draftObject

Returns the value of attribute template_draft.



36
37
38
# File 'lib/embed_workflow/models/update_workflow_request.rb', line 36

def template_draft
  @template_draft
end

#trigger_conditions_draftObject

The trigger’s conditions



39
40
41
# File 'lib/embed_workflow/models/update_workflow_request.rb', line 39

def trigger_conditions_draft
  @trigger_conditions_draft
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/embed_workflow/models/update_workflow_request.rb', line 242

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = EmbedWorkflow.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



68
69
70
# File 'lib/embed_workflow/models/update_workflow_request.rb', line 68

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/embed_workflow/models/update_workflow_request.rb', line 51

def self.attribute_map
  {
    :'name' => :'name',
    :'key' => :'key',
    :'auto_clone_for_new_users' => :'auto_clone_for_new_users',
    :'is_template' => :'is_template',
    :'on' => :'on',
    :'details' => :'details',
    :'template_draft' => :'template_draft',
    :'trigger_conditions_draft' => :'trigger_conditions_draft',
    :'event_trigger_draft' => :'event_trigger_draft',
    :'match_conditions_draft' => :'match_conditions_draft',
    :'groups' => :'groups'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/embed_workflow/models/update_workflow_request.rb', line 218

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



90
91
92
93
# File 'lib/embed_workflow/models/update_workflow_request.rb', line 90

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/embed_workflow/models/update_workflow_request.rb', line 73

def self.openapi_types
  {
    :'name' => :'String',
    :'key' => :'String',
    :'auto_clone_for_new_users' => :'Boolean',
    :'is_template' => :'Boolean',
    :'on' => :'Boolean',
    :'details' => :'String',
    :'template_draft' => :'CreateWorkflowRequestTemplateDraft',
    :'trigger_conditions_draft' => :'Object',
    :'event_trigger_draft' => :'String',
    :'match_conditions_draft' => :'String',
    :'groups' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/embed_workflow/models/update_workflow_request.rb', line 187

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      key == o.key &&
      auto_clone_for_new_users == o.auto_clone_for_new_users &&
      is_template == o.is_template &&
      on == o.on &&
      details == o.details &&
      template_draft == o.template_draft &&
      trigger_conditions_draft == o.trigger_conditions_draft &&
      event_trigger_draft == o.event_trigger_draft &&
      match_conditions_draft == o.match_conditions_draft &&
      groups == o.groups
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



313
314
315
316
317
318
319
320
321
322
323
324
325
# File 'lib/embed_workflow/models/update_workflow_request.rb', line 313

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


205
206
207
# File 'lib/embed_workflow/models/update_workflow_request.rb', line 205

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



211
212
213
# File 'lib/embed_workflow/models/update_workflow_request.rb', line 211

def hash
  [name, key, auto_clone_for_new_users, is_template, on, details, template_draft, trigger_conditions_draft, event_trigger_draft, match_conditions_draft, groups].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



167
168
169
170
171
172
173
174
175
# File 'lib/embed_workflow/models/update_workflow_request.rb', line 167

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



289
290
291
# File 'lib/embed_workflow/models/update_workflow_request.rb', line 289

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



295
296
297
298
299
300
301
302
303
304
305
306
307
# File 'lib/embed_workflow/models/update_workflow_request.rb', line 295

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



283
284
285
# File 'lib/embed_workflow/models/update_workflow_request.rb', line 283

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



179
180
181
182
183
# File 'lib/embed_workflow/models/update_workflow_request.rb', line 179

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  true
end