Class: EmbedWorkflow::ListWorkflows200ResponseCollectionInner
- Inherits:
-
Object
- Object
- EmbedWorkflow::ListWorkflows200ResponseCollectionInner
- Defined in:
- lib/embed_workflow/models/list_workflows200_response_collection_inner.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#action_type_ids ⇒ Object
Action type IDs used in this workflow’s template.
-
#actions_count ⇒ Object
Number of actions in the workflow.
-
#created_at ⇒ Object
Created at in specified timezone.
-
#created_at_string ⇒ Object
Created at formatted as human-readable string.
-
#created_at_utc ⇒ Object
Created at in UTC.
-
#description ⇒ Object
Description of the workflow.
-
#event_trigger ⇒ Object
Event trigger configuration.
-
#event_trigger_draft ⇒ Object
Draft event trigger configuration.
-
#executions_count ⇒ Object
Number of times workflow has been executed.
-
#has_draft ⇒ Object
Whether the workflow has unsaved draft changes.
-
#id ⇒ Object
Unique identifier.
-
#is_managed ⇒ Object
Whether this workflow is managed by the account and read-only.
-
#key ⇒ Object
Unique key for the workflow.
-
#last_executed_at ⇒ Object
Last executed at in specified timezone.
-
#last_executed_at_string ⇒ Object
Last executed at formatted as human-readable string.
-
#last_executed_at_utc ⇒ Object
Last executed at in UTC.
-
#last_published_at ⇒ Object
Last published at in specified timezone.
-
#last_published_at_string ⇒ Object
Last published at formatted as human-readable string.
-
#last_published_at_utc ⇒ Object
Last published at in UTC.
-
#match_conditions ⇒ Object
Conditions for matching workflow execution.
-
#match_conditions_draft ⇒ Object
Draft conditions for matching workflow execution.
-
#name ⇒ Object
Name of the workflow.
-
#object ⇒ Object
Object type identifier.
-
#on ⇒ Object
Whether the workflow is enabled.
-
#status ⇒ Object
Current status of the workflow.
-
#trigger_conditions ⇒ Object
Conditions for triggering the workflow.
-
#trigger_conditions_draft ⇒ Object
Draft conditions for triggering the workflow.
-
#updated_at ⇒ Object
Updated at in specified timezone.
-
#updated_at_string ⇒ Object
Updated at formatted as human-readable string.
-
#updated_at_utc ⇒ Object
Updated at in UTC.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListWorkflows200ResponseCollectionInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ListWorkflows200ResponseCollectionInner
Initializes the object
232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 232 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `EmbedWorkflow::ListWorkflows200ResponseCollectionInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `EmbedWorkflow::ListWorkflows200ResponseCollectionInner`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'action_type_ids') if (value = attributes[:'action_type_ids']).is_a?(Array) self.action_type_ids = value end end if attributes.key?(:'actions_count') self.actions_count = attributes[:'actions_count'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'created_at_string') self.created_at_string = attributes[:'created_at_string'] end if attributes.key?(:'created_at_utc') self.created_at_utc = attributes[:'created_at_utc'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'event_trigger') self.event_trigger = attributes[:'event_trigger'] end if attributes.key?(:'event_trigger_draft') self.event_trigger_draft = attributes[:'event_trigger_draft'] end if attributes.key?(:'executions_count') self.executions_count = attributes[:'executions_count'] end if attributes.key?(:'has_draft') self.has_draft = attributes[:'has_draft'] end if attributes.key?(:'is_managed') self.is_managed = attributes[:'is_managed'] end if attributes.key?(:'key') self.key = attributes[:'key'] end if attributes.key?(:'last_executed_at') self.last_executed_at = attributes[:'last_executed_at'] end if attributes.key?(:'last_executed_at_string') self.last_executed_at_string = attributes[:'last_executed_at_string'] end if attributes.key?(:'last_executed_at_utc') self.last_executed_at_utc = attributes[:'last_executed_at_utc'] end if attributes.key?(:'last_published_at') self.last_published_at = attributes[:'last_published_at'] end if attributes.key?(:'last_published_at_string') self.last_published_at_string = attributes[:'last_published_at_string'] end if attributes.key?(:'last_published_at_utc') self.last_published_at_utc = attributes[:'last_published_at_utc'] end if attributes.key?(:'match_conditions') self.match_conditions = attributes[:'match_conditions'] end if attributes.key?(:'match_conditions_draft') self.match_conditions_draft = attributes[:'match_conditions_draft'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'object') self.object = attributes[:'object'] end if attributes.key?(:'on') self.on = attributes[:'on'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'trigger_conditions') if (value = attributes[:'trigger_conditions']).is_a?(Hash) self.trigger_conditions = value end end if attributes.key?(:'trigger_conditions_draft') if (value = attributes[:'trigger_conditions_draft']).is_a?(Hash) self.trigger_conditions_draft = value end end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end if attributes.key?(:'updated_at_string') self.updated_at_string = attributes[:'updated_at_string'] end if attributes.key?(:'updated_at_utc') self.updated_at_utc = attributes[:'updated_at_utc'] end end |
Instance Attribute Details
#action_type_ids ⇒ Object
Action type IDs used in this workflow’s template
22 23 24 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 22 def action_type_ids @action_type_ids end |
#actions_count ⇒ Object
Number of actions in the workflow
25 26 27 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 25 def actions_count @actions_count end |
#created_at ⇒ Object
Created at in specified timezone
28 29 30 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 28 def created_at @created_at end |
#created_at_string ⇒ Object
Created at formatted as human-readable string
31 32 33 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 31 def created_at_string @created_at_string end |
#created_at_utc ⇒ Object
Created at in UTC
34 35 36 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 34 def created_at_utc @created_at_utc end |
#description ⇒ Object
Description of the workflow
37 38 39 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 37 def description @description end |
#event_trigger ⇒ Object
Event trigger configuration
40 41 42 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 40 def event_trigger @event_trigger end |
#event_trigger_draft ⇒ Object
Draft event trigger configuration
43 44 45 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 43 def event_trigger_draft @event_trigger_draft end |
#executions_count ⇒ Object
Number of times workflow has been executed
46 47 48 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 46 def executions_count @executions_count end |
#has_draft ⇒ Object
Whether the workflow has unsaved draft changes
49 50 51 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 49 def has_draft @has_draft end |
#id ⇒ Object
Unique identifier
19 20 21 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 19 def id @id end |
#is_managed ⇒ Object
Whether this workflow is managed by the account and read-only
52 53 54 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 52 def is_managed @is_managed end |
#key ⇒ Object
Unique key for the workflow
55 56 57 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 55 def key @key end |
#last_executed_at ⇒ Object
Last executed at in specified timezone
58 59 60 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 58 def last_executed_at @last_executed_at end |
#last_executed_at_string ⇒ Object
Last executed at formatted as human-readable string
61 62 63 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 61 def last_executed_at_string @last_executed_at_string end |
#last_executed_at_utc ⇒ Object
Last executed at in UTC
64 65 66 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 64 def last_executed_at_utc @last_executed_at_utc end |
#last_published_at ⇒ Object
Last published at in specified timezone
67 68 69 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 67 def last_published_at @last_published_at end |
#last_published_at_string ⇒ Object
Last published at formatted as human-readable string
70 71 72 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 70 def last_published_at_string @last_published_at_string end |
#last_published_at_utc ⇒ Object
Last published at in UTC
73 74 75 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 73 def last_published_at_utc @last_published_at_utc end |
#match_conditions ⇒ Object
Conditions for matching workflow execution
76 77 78 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 76 def match_conditions @match_conditions end |
#match_conditions_draft ⇒ Object
Draft conditions for matching workflow execution
79 80 81 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 79 def match_conditions_draft @match_conditions_draft end |
#name ⇒ Object
Name of the workflow
82 83 84 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 82 def name @name end |
#object ⇒ Object
Object type identifier
85 86 87 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 85 def object @object end |
#on ⇒ Object
Whether the workflow is enabled
88 89 90 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 88 def on @on end |
#status ⇒ Object
Current status of the workflow
91 92 93 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 91 def status @status end |
#trigger_conditions ⇒ Object
Conditions for triggering the workflow
94 95 96 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 94 def trigger_conditions @trigger_conditions end |
#trigger_conditions_draft ⇒ Object
Draft conditions for triggering the workflow
97 98 99 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 97 def trigger_conditions_draft @trigger_conditions_draft end |
#updated_at ⇒ Object
Updated at in specified timezone
100 101 102 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 100 def updated_at @updated_at end |
#updated_at_string ⇒ Object
Updated at formatted as human-readable string
103 104 105 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 103 def updated_at_string @updated_at_string end |
#updated_at_utc ⇒ Object
Updated at in UTC
106 107 108 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 106 def updated_at_utc @updated_at_utc end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 475 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = EmbedWorkflow.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
167 168 169 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 167 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 131 def self.attribute_map { :'id' => :'id', :'action_type_ids' => :'action_type_ids', :'actions_count' => :'actions_count', :'created_at' => :'created_at', :'created_at_string' => :'created_at_string', :'created_at_utc' => :'created_at_utc', :'description' => :'description', :'event_trigger' => :'event_trigger', :'event_trigger_draft' => :'event_trigger_draft', :'executions_count' => :'executions_count', :'has_draft' => :'has_draft', :'is_managed' => :'is_managed', :'key' => :'key', :'last_executed_at' => :'last_executed_at', :'last_executed_at_string' => :'last_executed_at_string', :'last_executed_at_utc' => :'last_executed_at_utc', :'last_published_at' => :'last_published_at', :'last_published_at_string' => :'last_published_at_string', :'last_published_at_utc' => :'last_published_at_utc', :'match_conditions' => :'match_conditions', :'match_conditions_draft' => :'match_conditions_draft', :'name' => :'name', :'object' => :'object', :'on' => :'on', :'status' => :'status', :'trigger_conditions' => :'trigger_conditions', :'trigger_conditions_draft' => :'trigger_conditions_draft', :'updated_at' => :'updated_at', :'updated_at_string' => :'updated_at_string', :'updated_at_utc' => :'updated_at_utc' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 451 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 208 def self.openapi_nullable Set.new([ :'created_at', :'created_at_string', :'created_at_utc', :'description', :'event_trigger', :'event_trigger_draft', :'last_executed_at', :'last_executed_at_string', :'last_executed_at_utc', :'last_published_at', :'last_published_at_string', :'last_published_at_utc', :'match_conditions', :'match_conditions_draft', :'updated_at', :'updated_at_string', :'updated_at_utc' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 172 def self.openapi_types { :'id' => :'String', :'action_type_ids' => :'Array<String>', :'actions_count' => :'Integer', :'created_at' => :'String', :'created_at_string' => :'String', :'created_at_utc' => :'String', :'description' => :'String', :'event_trigger' => :'Object', :'event_trigger_draft' => :'Object', :'executions_count' => :'Integer', :'has_draft' => :'Boolean', :'is_managed' => :'Boolean', :'key' => :'String', :'last_executed_at' => :'String', :'last_executed_at_string' => :'String', :'last_executed_at_utc' => :'String', :'last_published_at' => :'String', :'last_published_at_string' => :'String', :'last_published_at_utc' => :'String', :'match_conditions' => :'Object', :'match_conditions_draft' => :'Object', :'name' => :'String', :'object' => :'String', :'on' => :'Boolean', :'status' => :'String', :'trigger_conditions' => :'Hash<String, Object>', :'trigger_conditions_draft' => :'Hash<String, Object>', :'updated_at' => :'String', :'updated_at_string' => :'String', :'updated_at_utc' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 401 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && action_type_ids == o.action_type_ids && actions_count == o.actions_count && created_at == o.created_at && created_at_string == o.created_at_string && created_at_utc == o.created_at_utc && description == o.description && event_trigger == o.event_trigger && event_trigger_draft == o.event_trigger_draft && executions_count == o.executions_count && has_draft == o.has_draft && is_managed == o.is_managed && key == o.key && last_executed_at == o.last_executed_at && last_executed_at_string == o.last_executed_at_string && last_executed_at_utc == o.last_executed_at_utc && last_published_at == o.last_published_at && last_published_at_string == o.last_published_at_string && last_published_at_utc == o.last_published_at_utc && match_conditions == o.match_conditions && match_conditions_draft == o.match_conditions_draft && name == o.name && object == o.object && on == o.on && status == o.status && trigger_conditions == o.trigger_conditions && trigger_conditions_draft == o.trigger_conditions_draft && updated_at == o.updated_at && updated_at_string == o.updated_at_string && updated_at_utc == o.updated_at_utc end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
546 547 548 549 550 551 552 553 554 555 556 557 558 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 546 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
438 439 440 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 438 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
444 445 446 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 444 def hash [id, action_type_ids, actions_count, created_at, created_at_string, created_at_utc, description, event_trigger, event_trigger_draft, executions_count, has_draft, is_managed, key, last_executed_at, last_executed_at_string, last_executed_at_utc, last_published_at, last_published_at_string, last_published_at_utc, match_conditions, match_conditions_draft, name, object, on, status, trigger_conditions, trigger_conditions_draft, updated_at, updated_at_string, updated_at_utc].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
374 375 376 377 378 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 374 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
522 523 524 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 522 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
528 529 530 531 532 533 534 535 536 537 538 539 540 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 528 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
516 517 518 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 516 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
382 383 384 385 386 387 |
# File 'lib/embed_workflow/models/list_workflows200_response_collection_inner.rb', line 382 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' status_validator = EnumAttributeValidator.new('String', ["on", "off"]) return false unless status_validator.valid?(@status) true end |