Class: EmbedWorkflow::UpdateActionTypeRequest
- Inherits:
-
Object
- Object
- EmbedWorkflow::UpdateActionTypeRequest
- Defined in:
- lib/embed_workflow/models/update_action_type_request.rb
Instance Attribute Summary collapse
-
#callback_timeout_n ⇒ Object
Callback timeout duration value.
-
#callback_timeout_unit ⇒ Object
Callback timeout duration unit (sec, min, hour, day, week, month, year).
-
#code_draft ⇒ Object
JavaScript code snippt.
-
#description ⇒ Object
Description of action type.
-
#form_draft ⇒ Object
Form field configuration.
-
#groups ⇒ Object
User permission groups.
-
#headers_draft ⇒ Object
HTTP headers as key:value pairs, one per line.
-
#http_method_draft ⇒ Object
HTTP method.
-
#icon_draft ⇒ Object
Returns the value of attribute icon_draft.
-
#name ⇒ Object
Name of resource.
-
#on ⇒ Object
Enable or disable the resource.
-
#params_draft ⇒ Object
HTTP parameters as key:value pairs, one per line.
-
#primary_category ⇒ Object
Primary category for the action type.
-
#response_data_schema_draft ⇒ Object
Data schema configuration.
-
#secondary_category ⇒ Object
Secondary category for the action type.
-
#url_draft ⇒ Object
HTTP url.
-
#wait_for_callback ⇒ Object
When true, actions fire the webhook but wait for an external callback before completing.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateActionTypeRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateActionTypeRequest
Initializes the object
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/embed_workflow/models/update_action_type_request.rb', line 127 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `EmbedWorkflow::UpdateActionTypeRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `EmbedWorkflow::UpdateActionTypeRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'on') self.on = attributes[:'on'] else self.on = true end if attributes.key?(:'params_draft') self.params_draft = attributes[:'params_draft'] end if attributes.key?(:'headers_draft') self.headers_draft = attributes[:'headers_draft'] end if attributes.key?(:'url_draft') self.url_draft = attributes[:'url_draft'] end if attributes.key?(:'http_method_draft') self.http_method_draft = attributes[:'http_method_draft'] end if attributes.key?(:'code_draft') self.code_draft = attributes[:'code_draft'] end if attributes.key?(:'form_draft') if (value = attributes[:'form_draft']).is_a?(Array) self.form_draft = value end end if attributes.key?(:'response_data_schema_draft') if (value = attributes[:'response_data_schema_draft']).is_a?(Array) self.response_data_schema_draft = value end end if attributes.key?(:'groups') if (value = attributes[:'groups']).is_a?(Array) self.groups = value end end if attributes.key?(:'icon_draft') self.icon_draft = attributes[:'icon_draft'] end if attributes.key?(:'primary_category') self.primary_category = attributes[:'primary_category'] end if attributes.key?(:'secondary_category') self.secondary_category = attributes[:'secondary_category'] end if attributes.key?(:'wait_for_callback') self.wait_for_callback = attributes[:'wait_for_callback'] else self.wait_for_callback = false end if attributes.key?(:'callback_timeout_n') self.callback_timeout_n = attributes[:'callback_timeout_n'] end if attributes.key?(:'callback_timeout_unit') self.callback_timeout_unit = attributes[:'callback_timeout_unit'] end end |
Instance Attribute Details
#callback_timeout_n ⇒ Object
Callback timeout duration value
63 64 65 |
# File 'lib/embed_workflow/models/update_action_type_request.rb', line 63 def callback_timeout_n @callback_timeout_n end |
#callback_timeout_unit ⇒ Object
Callback timeout duration unit (sec, min, hour, day, week, month, year)
66 67 68 |
# File 'lib/embed_workflow/models/update_action_type_request.rb', line 66 def callback_timeout_unit @callback_timeout_unit end |
#code_draft ⇒ Object
JavaScript code snippt
40 41 42 |
# File 'lib/embed_workflow/models/update_action_type_request.rb', line 40 def code_draft @code_draft end |
#description ⇒ Object
Description of action type
22 23 24 |
# File 'lib/embed_workflow/models/update_action_type_request.rb', line 22 def description @description end |
#form_draft ⇒ Object
Form field configuration
43 44 45 |
# File 'lib/embed_workflow/models/update_action_type_request.rb', line 43 def form_draft @form_draft end |
#groups ⇒ Object
User permission groups. Only available to users with admin role.
49 50 51 |
# File 'lib/embed_workflow/models/update_action_type_request.rb', line 49 def groups @groups end |
#headers_draft ⇒ Object
HTTP headers as key:value pairs, one per line
31 32 33 |
# File 'lib/embed_workflow/models/update_action_type_request.rb', line 31 def headers_draft @headers_draft end |
#http_method_draft ⇒ Object
HTTP method
37 38 39 |
# File 'lib/embed_workflow/models/update_action_type_request.rb', line 37 def http_method_draft @http_method_draft end |
#icon_draft ⇒ Object
Returns the value of attribute icon_draft.
51 52 53 |
# File 'lib/embed_workflow/models/update_action_type_request.rb', line 51 def icon_draft @icon_draft end |
#name ⇒ Object
Name of resource
19 20 21 |
# File 'lib/embed_workflow/models/update_action_type_request.rb', line 19 def name @name end |
#on ⇒ Object
Enable or disable the resource.
25 26 27 |
# File 'lib/embed_workflow/models/update_action_type_request.rb', line 25 def on @on end |
#params_draft ⇒ Object
HTTP parameters as key:value pairs, one per line
28 29 30 |
# File 'lib/embed_workflow/models/update_action_type_request.rb', line 28 def params_draft @params_draft end |
#primary_category ⇒ Object
Primary category for the action type
54 55 56 |
# File 'lib/embed_workflow/models/update_action_type_request.rb', line 54 def primary_category @primary_category end |
#response_data_schema_draft ⇒ Object
Data schema configuration
46 47 48 |
# File 'lib/embed_workflow/models/update_action_type_request.rb', line 46 def response_data_schema_draft @response_data_schema_draft end |
#secondary_category ⇒ Object
Secondary category for the action type
57 58 59 |
# File 'lib/embed_workflow/models/update_action_type_request.rb', line 57 def secondary_category @secondary_category end |
#url_draft ⇒ Object
HTTP url
34 35 36 |
# File 'lib/embed_workflow/models/update_action_type_request.rb', line 34 def url_draft @url_draft end |
#wait_for_callback ⇒ Object
When true, actions fire the webhook but wait for an external callback before completing
60 61 62 |
# File 'lib/embed_workflow/models/update_action_type_request.rb', line 60 def wait_for_callback @wait_for_callback end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/embed_workflow/models/update_action_type_request.rb', line 297 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = EmbedWorkflow.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
92 93 94 |
# File 'lib/embed_workflow/models/update_action_type_request.rb', line 92 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/embed_workflow/models/update_action_type_request.rb', line 69 def self.attribute_map { :'name' => :'name', :'description' => :'description', :'on' => :'on', :'params_draft' => :'params_draft', :'headers_draft' => :'headers_draft', :'url_draft' => :'url_draft', :'http_method_draft' => :'http_method_draft', :'code_draft' => :'code_draft', :'form_draft' => :'form_draft', :'response_data_schema_draft' => :'response_data_schema_draft', :'groups' => :'groups', :'icon_draft' => :'icon_draft', :'primary_category' => :'primary_category', :'secondary_category' => :'secondary_category', :'wait_for_callback' => :'wait_for_callback', :'callback_timeout_n' => :'callback_timeout_n', :'callback_timeout_unit' => :'callback_timeout_unit' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'lib/embed_workflow/models/update_action_type_request.rb', line 273 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
120 121 122 123 |
# File 'lib/embed_workflow/models/update_action_type_request.rb', line 120 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/embed_workflow/models/update_action_type_request.rb', line 97 def self.openapi_types { :'name' => :'String', :'description' => :'String', :'on' => :'Boolean', :'params_draft' => :'String', :'headers_draft' => :'String', :'url_draft' => :'String', :'http_method_draft' => :'String', :'code_draft' => :'String', :'form_draft' => :'Array<CreateActionTypeRequestFormDraftInner>', :'response_data_schema_draft' => :'Array<UpdateAccountRequestUserDataSchemaInner>', :'groups' => :'Array<String>', :'icon_draft' => :'CreateActionTypeRequestIconDraft', :'primary_category' => :'String', :'secondary_category' => :'String', :'wait_for_callback' => :'Boolean', :'callback_timeout_n' => :'Integer', :'callback_timeout_unit' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/embed_workflow/models/update_action_type_request.rb', line 236 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && description == o.description && on == o.on && params_draft == o.params_draft && headers_draft == o.headers_draft && url_draft == o.url_draft && http_method_draft == o.http_method_draft && code_draft == o.code_draft && form_draft == o.form_draft && response_data_schema_draft == o.response_data_schema_draft && groups == o.groups && icon_draft == o.icon_draft && primary_category == o.primary_category && secondary_category == o.secondary_category && wait_for_callback == o.wait_for_callback && callback_timeout_n == o.callback_timeout_n && callback_timeout_unit == o.callback_timeout_unit end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/embed_workflow/models/update_action_type_request.rb', line 368 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
260 261 262 |
# File 'lib/embed_workflow/models/update_action_type_request.rb', line 260 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
266 267 268 |
# File 'lib/embed_workflow/models/update_action_type_request.rb', line 266 def hash [name, description, on, params_draft, headers_draft, url_draft, http_method_draft, code_draft, form_draft, response_data_schema_draft, groups, icon_draft, primary_category, secondary_category, wait_for_callback, callback_timeout_n, callback_timeout_unit].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
221 222 223 224 225 |
# File 'lib/embed_workflow/models/update_action_type_request.rb', line 221 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
344 345 346 |
# File 'lib/embed_workflow/models/update_action_type_request.rb', line 344 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
350 351 352 353 354 355 356 357 358 359 360 361 362 |
# File 'lib/embed_workflow/models/update_action_type_request.rb', line 350 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
338 339 340 |
# File 'lib/embed_workflow/models/update_action_type_request.rb', line 338 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
229 230 231 232 |
# File 'lib/embed_workflow/models/update_action_type_request.rb', line 229 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |